package org.greenstone.gatherer.metadata;


/** This class is a static class containing useful metadata functions */
public class MetadataTools
{
    static final public String NAMESPACE_SEPARATOR = ".";


    static public String getMetadataElementName(String metadata_element_name_full)
    {
	// Full element name contains namespace
	if (metadata_element_name_full.indexOf(NAMESPACE_SEPARATOR) != -1) {
	    return metadata_element_name_full.substring(metadata_element_name_full.indexOf(NAMESPACE_SEPARATOR) + 1);
	}

	// No namespace
	return metadata_element_name_full;      
    }


    static public String getMetadataElementAttribute(MetadataElement metadata_element, String attribute_name, String language_code, String fallback_language_code)
    {
	String metadata_element_attribute = metadata_element.getAttribute(attribute_name, language_code);

	// If the attribute isn't defined in the desired language, resort to the fallback
	if (metadata_element_attribute == null && !language_code.equals(fallback_language_code)) {
	    metadata_element_attribute = metadata_element.getAttribute(attribute_name, fallback_language_code);
	}

	return metadata_element_attribute;
    }


    static public String getMetadataSetAttribute(MetadataSet metadata_set, String attribute_name, String language_code, String fallback_language_code)
    {
	String metadata_set_attribute = metadata_set.getAttribute(attribute_name, language_code);

	// If the attribute isn't defined in the desired language, resort to the fallback
	if (metadata_set_attribute == null && !language_code.equals(fallback_language_code)) {
	    metadata_set_attribute = metadata_set.getAttribute(attribute_name, fallback_language_code);
	}

	return metadata_set_attribute;
    }


    static public String getMetadataSetNamespace(String metadata_element_name_full)
    {
	// Full element name contains namespace
	if (metadata_element_name_full.indexOf(NAMESPACE_SEPARATOR) != -1) {
	    return metadata_element_name_full.substring(0, metadata_element_name_full.indexOf(NAMESPACE_SEPARATOR));
	}

	// No namespace
	return "";
    }
}
