###########################################################################
#
# HTML.pm --
# A component of the Greenstone digital library software
# from the New Zealand Digital Library Project at the 
# University of Waikato, New Zealand.
#
# Copyright (C) 1999 New Zealand Digital Library Project
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
###########################################################################

# html classifier plugin - creates an empty classification
# that's simply a link to a web page

package HTML;

use BasClas;

sub BEGIN {
    @ISA = ('BasClas');
}

my $arguments = 
    [ { 'name' => "url",
	'desc' => "{HTML.url}",
	'type' => "string",
	'reqd' => "yes" } ,
      { 'name' => "buttonname",
	'desc' => "{BasClas.buttonname}",
	'type' => "string",
	'deft' => "Browse",
	'reqd' => "no" } ];

my $options = { 'name'     => "HTML",
		'desc'     => "{HTML.desc}",
		'abstract' => "no",
		'inherits' => "yes",
		'args'     => $arguments };


sub new {
    my $class = shift (@_);
    my $self = new BasClas($class, @_);

    # 14-05-02 To allow for proper inheritance of arguments - John Thompson
    my $option_list = $self->{'option_list'};
    push( @{$option_list}, $options );

    if ($self->{'info_only'}) {
	# created from classinfo.pl - don't need to parse the arguments
	return bless $self, $class;
    }

    my ($title, $url);
    
    if (!parsargv::parse(\@_, 
			 q^url/.*/^, \$url,
			 q^buttonname/.*/Browse^, \$title,
			 "allow_extra_options")) {
	
	print STDERR "\nIncorrect options passed to $class, check your collect.cfg file\n";
	$self->print_txt_usage("");  # Use default resource bundle
	die "\n";
    }

    if (!$url) {
	my $outhandle = $self->{'outhandle'};
	print $outhandle "HTML Error: required option -url not supplied\n";
	$self->print_txt_usage("");
	die "HTML Error: required option -url not supplied\n";
    }

    $self->{'url'} = $url;
    $self->{'title'} = $title;

    return bless $self, $class;
}

sub init {
    my $self = shift (@_);
}

sub classify {
    my $self = shift (@_);
    my ($doc_obj) = @_;

    # we don't do anything for individual documents
}

sub get_classify_info {
    my $self = shift (@_);

    my %classifyinfo = ('thistype'=>'Invisible',
			'childtype'=>'HTML',
			'Title'=>$self->{'title'},
			'contains'=>[]);

    push (@{$classifyinfo{'contains'}}, {'OID'=>$self->{'url'}});

    return \%classifyinfo;
}


1;
